==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/accountmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>AccountManager</name>
    <message>
        <source>Accounts</source>
        <translation>Konten</translation>
    </message>
    <message>
        <source>Modify account</source>
        <translation>Konto bearbeiten</translation>
    </message>
    <message>
        <source>Account Manager</source>
        <translation>Konto Manager</translation>
    </message>
    <message>
        <source>Allows to create and manage Jabber accounts</source>
        <translation>ErmÃ¶glicht das Erstellen und verwalten von Jabber Konten</translation>
    </message>
    <message>
        <source>Require a secure connection</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountOptions</name>
    <message>
        <source>New Account</source>
        <translation>Neues Konto</translation>
    </message>
    <message>
        <source>Invalid Account</source>
        <translation></translation>
    </message>
    <message>
        <source>Account &apos;%1&apos; is not valid, change its Jabber ID</source>
        <translation></translation>
    </message>
    <message>
        <source>Delayed Apply</source>
        <translation></translation>
    </message>
    <message>
        <source>Some options of account &apos;%1&apos; will be applied after disconnect</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountOptionsClass</name>
    <message>
        <source>Account Name:</source>
        <translation>Konto Name:</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Example: romeo@example.net</source>
        <translation>Beispiel: romeo@example.net</translation>
    </message>
    <message>
        <source>Jabber ID:</source>
        <translation>Jabber ID:</translation>
    </message>
    <message>
        <source>Resource:</source>
        <translation>Resource:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Example: home; office; notebook</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountsOptions</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Jabber ID</source>
        <translation>Jabber ID</translation>
    </message>
    <message>
        <source>Confirm removal of an account</source>
        <translation>Entfernen des Kontos bestätigen</translation>
    </message>
    <message>
        <source>You are assured that wish to remove an account &lt;b&gt;%1&lt;/b&gt;?&lt;br&gt;All settings will be lost.</source>
        <translation></translation>
    </message>
    <message>
        <source>New Account</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountsOptionsClass</name>
    <message>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/accountmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>AccountManager</name>
    <message>
        <source>Accounts</source>
        <translation>Konten</translation>
    </message>
    <message>
        <source>Modify account</source>
        <translation>Konto bearbeiten</translation>
    </message>
    <message>
        <source>Account Manager</source>
        <translation>Konto Manager</translation>
    </message>
    <message>
        <source>Allows to create and manage Jabber accounts</source>
        <translation>Ermöglicht das Erstellen und verwalten von Jabber Konten</translation>
    </message>
    <message>
        <source>Require a secure connection</source>
        <translation>Benötigt eine sichere Verbindung</translation>
    </message>
</context>
<context>
    <name>AccountOptions</name>
    <message>
        <source>New Account</source>
        <translation>Neues Konto</translation>
    </message>
    <message>
        <source>Invalid Account</source>
        <translation>Ungültiges Konto</translation>
    </message>
    <message>
        <source>Account &apos;%1&apos; is not valid, change its Jabber ID</source>
        <translation>Konto &apos;%1&apos; ist nicht gültig, Jabber ID ändern</translation>
    </message>
    <message>
        <source>Delayed Apply</source>
        <translation>Verzögerte Übernahme</translation>
    </message>
    <message>
        <source>Some options of account &apos;%1&apos; will be applied after disconnect</source>
        <translation>Einige Optionen des Kontos &apos;%1&apos; werden erst nach dem trennen der Verbindung wirksam</translation>
    </message>
</context>
<context>
    <name>AccountOptionsClass</name>
    <message>
        <source>Account Name:</source>
        <translation>Konto Name:</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Example: romeo@example.net</source>
        <translation>Beispiel: romeo@example.net</translation>
    </message>
    <message>
        <source>Jabber ID:</source>
        <translation>Jabber ID:</translation>
    </message>
    <message>
        <source>Resource:</source>
        <translation>Resource:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Example: home; office; notebook</source>
        <translation>Beispiel: home; office; notebook</translation>
    </message>
</context>
<context>
    <name>AccountsOptions</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Jabber ID</source>
        <translation>Jabber ID</translation>
    </message>
    <message>
        <source>Confirm removal of an account</source>
        <translation>Entfernen des Kontos bestätigen</translation>
    </message>
    <message>
        <source>You are assured that wish to remove an account &lt;b&gt;%1&lt;/b&gt;?&lt;br&gt;All settings will be lost.</source>
        <translation>Sind sie sicher, daß sie das Konto &lt;b&gt;%1&lt;/b&gt; löschen möchten?&lt;br&gt;Alle Einstellungen gehen verloren.</translation>
    </message>
    <message>
        <source>New Account</source>
        <translation>Neues Konto</translation>
    </message>
</context>
<context>
    <name>AccountsOptionsClass</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
</TS>
